==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/MessageArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.InformalArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgument;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.OperationArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.EventArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.ExecutablePropertyArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationArgumentSetImpl;

import java.util.Arrays;
import java.util.List;


public class MessageArgumentSetImpl extends InstanceSet<MessageArgumentSet,MessageArgument> implements MessageArgumentSet {

    // attributes
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setInformalName( m_InformalName );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setDescrip( m_Descrip );
    }
    @Override
    public void setInformal_Msg_ID( UniqueId ref_Informal_Msg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setInformal_Msg_ID( ref_Informal_Msg_ID );
    }
    @Override
    public void setFormal_Msg_ID( UniqueId ref_Formal_Msg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setFormal_Msg_ID( ref_Formal_Msg_ID );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setIsFormal( m_isFormal );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setLabel( m_Label );
    }
    @Override
    public void setArg_ID( UniqueId m_Arg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setArg_ID( m_Arg_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setValue( m_Value );
    }


    // selections
    @Override
    public MSG_MSet R1000_belongs_to_informal_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( MessageArgument messageargument : this ) msg_mset.add( messageargument.R1000_belongs_to_informal_MSG_M() );
        return msg_mset;
    }
    @Override
    public MSG_MSet R1001_belongs_to_formal_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( MessageArgument messageargument : this ) msg_mset.add( messageargument.R1001_belongs_to_formal_MSG_M() );
        return msg_mset;
    }
    @Override
    public BridgeArgumentSet R1013_is_a_BridgeArgument() throws XtumlException {
        BridgeArgumentSet bridgeargumentset = new BridgeArgumentSetImpl();
        for ( MessageArgument messageargument : this ) bridgeargumentset.add( messageargument.R1013_is_a_BridgeArgument() );
        return bridgeargumentset;
    }
    @Override
    public EventArgumentSet R1013_is_a_EventArgument() throws XtumlException {
        EventArgumentSet eventargumentset = new EventArgumentSetImpl();
        for ( MessageArgument messageargument : this ) eventargumentset.add( messageargument.R1013_is_a_EventArgument() );
        return eventargumentset;
    }
    @Override
    public ExecutablePropertyArgumentSet R1013_is_a_ExecutablePropertyArgument() throws XtumlException {
        ExecutablePropertyArgumentSet executablepropertyargumentset = new ExecutablePropertyArgumentSetImpl();
        for ( MessageArgument messageargument : this ) executablepropertyargumentset.add( messageargument.R1013_is_a_ExecutablePropertyArgument() );
        return executablepropertyargumentset;
    }
    @Override
    public FunctionArgumentSet R1013_is_a_FunctionArgument() throws XtumlException {
        FunctionArgumentSet functionargumentset = new FunctionArgumentSetImpl();
        for ( MessageArgument messageargument : this ) functionargumentset.add( messageargument.R1013_is_a_FunctionArgument() );
        return functionargumentset;
    }
    @Override
    public InformalArgumentSet R1013_is_a_InformalArgument() throws XtumlException {
        InformalArgumentSet informalargumentset = new InformalArgumentSetImpl();
        for ( MessageArgument messageargument : this ) informalargumentset.add( messageargument.R1013_is_a_InformalArgument() );
        return informalargumentset;
    }
    @Override
    public OperationArgumentSet R1013_is_a_OperationArgument() throws XtumlException {
        OperationArgumentSet operationargumentset = new OperationArgumentSetImpl();
        for ( MessageArgument messageargument : this ) operationargumentset.add( messageargument.R1013_is_a_OperationArgument() );
        return operationargumentset;
    }


    @Override
    public MessageArgument nullElement() {
        return MessageArgumentImpl.EMPTY_MESSAGEARGUMENT;
    }

    @Override
    public MessageArgumentSet emptySet() {
      return new MessageArgumentSetImpl();
    }

    @Override
    public MessageArgumentSet value() {
        return this;
    }

    @Override
    public List<MessageArgument> elements() {
        return Arrays.asList(toArray(new MessageArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/MessageArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.ExecutablePropertyArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.FunctionArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.InformalArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MSG_MSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgument;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.OperationArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.BridgeArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.EventArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.ExecutablePropertyArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.FunctionArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.InformalArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.MSG_MSetImpl;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationArgumentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class MessageArgumentSetImpl extends InstanceSet<MessageArgumentSet,MessageArgument> implements MessageArgumentSet {

    public MessageArgumentSetImpl() {
    }

    public MessageArgumentSetImpl(Comparator<? super MessageArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArg_ID( UniqueId m_Arg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setArg_ID( m_Arg_ID );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setIsFormal( m_isFormal );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setDescrip( m_Descrip );
    }
    @Override
    public void setInformal_Msg_ID( UniqueId ref_Informal_Msg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setInformal_Msg_ID( ref_Informal_Msg_ID );
    }
    @Override
    public void setFormal_Msg_ID( UniqueId ref_Formal_Msg_ID ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setFormal_Msg_ID( ref_Formal_Msg_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setLabel( m_Label );
    }
    @Override
    public void setInformalName( String m_InformalName ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setInformalName( m_InformalName );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( MessageArgument messageargument : this ) messageargument.setValue( m_Value );
    }


    // selections
    @Override
    public MSG_MSet R1000_belongs_to_informal_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( MessageArgument messageargument : this ) msg_mset.add( messageargument.R1000_belongs_to_informal_MSG_M() );
        return msg_mset;
    }
    @Override
    public MSG_MSet R1001_belongs_to_formal_MSG_M() throws XtumlException {
        MSG_MSet msg_mset = new MSG_MSetImpl();
        for ( MessageArgument messageargument : this ) msg_mset.add( messageargument.R1001_belongs_to_formal_MSG_M() );
        return msg_mset;
    }
    @Override
    public BridgeArgumentSet R1013_is_a_BridgeArgument() throws XtumlException {
        BridgeArgumentSet bridgeargumentset = new BridgeArgumentSetImpl();
        for ( MessageArgument messageargument : this ) bridgeargumentset.add( messageargument.R1013_is_a_BridgeArgument() );
        return bridgeargumentset;
    }
    @Override
    public EventArgumentSet R1013_is_a_EventArgument() throws XtumlException {
        EventArgumentSet eventargumentset = new EventArgumentSetImpl();
        for ( MessageArgument messageargument : this ) eventargumentset.add( messageargument.R1013_is_a_EventArgument() );
        return eventargumentset;
    }
    @Override
    public ExecutablePropertyArgumentSet R1013_is_a_ExecutablePropertyArgument() throws XtumlException {
        ExecutablePropertyArgumentSet executablepropertyargumentset = new ExecutablePropertyArgumentSetImpl();
        for ( MessageArgument messageargument : this ) executablepropertyargumentset.add( messageargument.R1013_is_a_ExecutablePropertyArgument() );
        return executablepropertyargumentset;
    }
    @Override
    public FunctionArgumentSet R1013_is_a_FunctionArgument() throws XtumlException {
        FunctionArgumentSet functionargumentset = new FunctionArgumentSetImpl();
        for ( MessageArgument messageargument : this ) functionargumentset.add( messageargument.R1013_is_a_FunctionArgument() );
        return functionargumentset;
    }
    @Override
    public InformalArgumentSet R1013_is_a_InformalArgument() throws XtumlException {
        InformalArgumentSet informalargumentset = new InformalArgumentSetImpl();
        for ( MessageArgument messageargument : this ) informalargumentset.add( messageargument.R1013_is_a_InformalArgument() );
        return informalargumentset;
    }
    @Override
    public OperationArgumentSet R1013_is_a_OperationArgument() throws XtumlException {
        OperationArgumentSet operationargumentset = new OperationArgumentSetImpl();
        for ( MessageArgument messageargument : this ) operationargumentset.add( messageargument.R1013_is_a_OperationArgument() );
        return operationargumentset;
    }


    @Override
    public MessageArgument nullElement() {
        return MessageArgumentImpl.EMPTY_MESSAGEARGUMENT;
    }

    @Override
    public MessageArgumentSet emptySet() {
      return new MessageArgumentSetImpl();
    }

    @Override
    public MessageArgumentSet emptySet(Comparator<? super MessageArgument> comp) {
      return new MessageArgumentSetImpl(comp);
    }

    @Override
    public MessageArgumentSet value() {
        return this;
    }

    @Override
    public List<MessageArgument> elements() {
        return Arrays.asList(toArray(new MessageArgument[0]));
    }

}
